/*
 *     Botendo
 *     Copyright (C) 2023  limited_dev
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package de.limited_dev.botendo.extensions.music

import com.kotlindiscord.kord.extensions.extensions.Extension
import com.kotlindiscord.kord.extensions.extensions.publicSlashCommand
import de.limited_dev.botendo.Bot
import de.limited_dev.botendo.util.MessageUtil
import de.limited_dev.botendo.util.TimeUtil
import de.limited_dev.botendo.util.UrlUtil
import dev.schlaubi.lavakord.audio.Link
import dev.schlaubi.lavakord.kord.getLink

class NowPlayingExtension : Extension() {
    override val name = "nowplaying"
    override suspend fun setup() {
        publicSlashCommand {
            name = "nowplaying"
            description = "Show what's currently playing"
            this.action {
                val guildId = this.guild!!.id
                val link = Bot.lava.getLink(guildId)
                val player = link.player
                if (link.state == Link.State.NOT_CONNECTED) {
                    MessageUtil.sendEmbedForPublicSlashCommand(
                        this,
                        "Not connected",
                        "I'm not in a VC and therefore, I am not playing anything."
                    )
                    return@action
                }
                val track = player.playingTrack
                if (track == null) {
                    MessageUtil.sendEmbedForPublicSlashCommand(
                        this,
                        "Not Playing",
                        "I'm not playing anything currently"
                    )
                    return@action
                }
                MessageUtil.sendEmbedForPublicSlashCommandWithImage(
                    this,
                    "Currently playing",
                    "**${track.title}**\n*Now Playing*\nby ${track.author} :${
                        TimeUtil.getTimeFormatedRaw(
                            track.position.inWholeMilliseconds
                        )
                    }: ${
                        TimeUtil.getTimeFormatedRaw(
                            track.length.inWholeMilliseconds
                        )
                    }\n" +
                            ">>>${track.uri}",
                    "https://img.youtube.com/vi/" + UrlUtil.getYtThumbnailUrl(track.uri!!) + "/maxresdefault.jpg"
                )
            }
        }
    }
}
