/*
 *     Botendo
 *     Copyright (C) 2023  limited_dev
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package de.limited_dev.botendo.extensions.music

import com.kotlindiscord.kord.extensions.extensions.Extension
import com.kotlindiscord.kord.extensions.extensions.publicSlashCommand
import de.limited_dev.botendo.Bot
import de.limited_dev.botendo.extensions.music.components.MusicManager
import de.limited_dev.botendo.util.MessageUtil
import de.limited_dev.botendo.util.TimeUtil
import de.limited_dev.botendo.util.UrlUtil
import dev.schlaubi.lavakord.audio.Link

class SkipExtension : Extension() {
    override val name = "skip"
    override suspend fun setup() {
        publicSlashCommand {
            name = "skip"
            description = "Skip to the next song in queue"
            this.action {
                val guildId = this.guild!!.id
                val link = Bot.lava.getLink(guildId.toString())
                val player = link.player
                val u = this.user
                val voiceState = u.asMember(guildId).getVoiceStateOrNull()
                if (voiceState == null) {
                    MessageUtil.sendEmbedForPublicSlashCommand(
                        this,
                        "You are not connected to a VC",
                        "Please connect to a VC"
                    )
                    return@action
                }

                val channelId = voiceState.channelId
                if (link.state == Link.State.NOT_CONNECTED) {
                    MessageUtil.sendEmbedForPublicSlashCommand(
                        this,
                        "Not connected",
                        "I'm not in a VC and therefore, I am not playing anything."
                    )
                    return@action
                } else if (link.state == Link.State.CONNECTED && link.lastChannelId != channelId!!.value) {
                    MessageUtil.sendEmbedForPublicSlashCommand(
                        this,
                        "You are not in my VC",
                        "We are not in the same VC and therefore, you cannot control the music"
                    )
                    return@action
                }
                var track = player.playingTrack
                if (track == null) {
                    MessageUtil.sendEmbedForPublicSlashCommand(
                        this,
                        "Not playing",
                        "I'm not playing anything currently"
                    )
                    return@action
                }
                val gts = MusicManager.getGuildTrackScheduler(this.guild!!.asGuild(), player)
                track = gts.getHead().toTrack()
                gts.playNext()
                MessageUtil.sendEmbedForPublicSlashCommandWithImage(
                    this,
                    "Skipped song; now playing",
                    "**${track.title}**\n*Now Playing*\nby ${track.author} :: ${
                        TimeUtil.getTimeFormatedRaw(
                            track.length.inWholeMilliseconds
                        )
                    }\n" +
                            ">>>${track.uri}",
                    "https://img.youtube.com/vi/" + UrlUtil.getYtThumbnailUrl(track.uri!!) + "/maxresdefault.jpg"

                )
            }
        }
    }
}
